@@ -111,6 +111,7 @@ int
 main(int argc,char **argv)
 {
   nco_bool ALPHABETIZE_OUTPUT=True; /* Option a */
+  nco_bool CPY_GRP_METADATA; /* [flg] Copy group metadata (attributes) */
   nco_bool EXCLUDE_INPUT_LIST=False; /* Option x */
   nco_bool EXTRACT_ALL_COORDINATES=False; /* Option c */
   nco_bool EXTRACT_ASSOCIATED_COORDINATES=True; /* Option C */
@@ -197,7 +198,7 @@ main(int argc,char **argv)
 
   const char * const CVS_Id="$Id$"; 
   const char * const CVS_Revision="$Revision$";
-  const char * const opt_sht_lst="34567aABb:CcD:d:FG:g:HhL:l:MmOo:Pp:qQrRs:uVv:X:xz-:";
+  const char * const opt_sht_lst="34567aABb:CcD:d:FG:g:HhL:l:MmOo:Pp:qQrRs:t:uVv:X:xz-:";
 
   cnk_sct cnk; /* [sct] Chunking structure */
 
@@ -208,6 +209,8 @@ main(int argc,char **argv)
   ddra_info_sct ddra_info={.flg_ddra=False};
 #endif /* !__cplusplus */
 
+  double wgt_vld_thr=NC_MIN_DOUBLE; /* [frc] Weight threshold for valid destination value */
+
   extern char *optarg;
   extern int optind;
 
@@ -215,6 +218,8 @@ main(int argc,char **argv)
 
   gpe_sct *gpe=NULL; /* [sng] Group Path Editing (GPE) structure */
 
+  int *in_id_arr; /* [id] netCDF file IDs used by OpenMP code */
+
   int abb_arg_nbr=0;
   int att_glb_nbr;
   int att_grp_nbr;
@@ -241,12 +246,13 @@ main(int argc,char **argv)
   int ppc_nbr=0; /* [nbr] Number of PPC arguments */
   int rgr_nbr=0; /* [nbr] Number of regridding arguments */
   int rcd=NC_NOERR; /* [rcd] Return code */
+  int thr_idx; /* [idx] Index of current thread */
+  int thr_nbr=int_CEWI; /* [nbr] Thread number Option t */
   int var_lst_in_nbr=0;
   int var_nbr_fl;
   int var_ntm_fl;
   int xtr_nbr=0; /* xtr_nbr will not otherwise be set for -c with no -v */
 
-  /* DYW */
   kvm_sct *sld_nfo=NULL; /* [sct] Container for SLD/SCRIP information */
 
   md5_sct *md5=NULL; /* [sct] MD5 configuration */
@@ -364,11 +370,14 @@ main(int argc,char **argv)
       {"rgr",required_argument,0,0}, /* [sng] Regridding */
       {"regridding",required_argument,0,0}, /* [sng] Regridding */
       {"rgr_in",required_argument,0,0}, /* [sng] File containing fields to be regridded */
-      {"rgr_out",required_argument,0,0}, /* [sng] File containing regridded fields */
       {"rgr_grd_src",required_argument,0,0}, /* [sng] File containing input grid */
       {"rgr_grd_dst",required_argument,0,0}, /* [sng] File containing destination grid */
       {"rgr_map",required_argument,0,0}, /* [sng] File containing mapping weights from source to destination grid */
+      {"map_file",required_argument,0,0}, /* [sng] File containing mapping weights from source to destination grid */
       {"rgr_var",required_argument,0,0}, /* I [sng] Variable for special regridding treatment */
+      {"rgr_rnr",required_argument,0,0}, /* [flg] Renormalize destination values by valid area */
+      {"rnr",required_argument,0,0}, /* [flg] Renormalize destination values by valid area */
+      {"renormalize",required_argument,0,0}, /* [flg] Renormalize destination values by valid area */
       {"scrip",required_argument,0,0}, /* SCRIP file */
       {"tst_udunits",required_argument,0,0},
       {"xml_spr_chr",required_argument,0,0}, /* [flg] Separator for XML character types */
@@ -430,6 +439,9 @@ main(int argc,char **argv)
       {"spinlock",no_argument,0,'S'}, /* [flg] Suspend with signal handler to facilitate debugging */
       {"sng_fmt",required_argument,0,'s'},
       {"string",required_argument,0,'s'},
+      {"thr_nbr",required_argument,0,'t'},
+      {"threads",required_argument,0,'t'},
+      {"omp_num_threads",required_argument,0,'t'},
       {"units",no_argument,0,'u'},
       {"var_val",no_argument,0,'V'}, /* [flg] Print variable values only */
       {"variable",required_argument,0,'v'},
@@ -574,24 +586,26 @@ main(int argc,char **argv)
       if(!strcmp(opt_crr,"no_blank") || !strcmp(opt_crr,"no-blank") || !strcmp(opt_crr,"noblank")) PRN_MSS_VAL_BLANK=!PRN_MSS_VAL_BLANK;
       if(!strcmp(opt_crr,"no_clb") || !strcmp(opt_crr,"no-clobber") || !strcmp(opt_crr,"no_clobber") || !strcmp(opt_crr,"noclobber")) FORCE_NOCLOBBER=!FORCE_NOCLOBBER;
       if(!strcmp(opt_crr,"no_nm_prn") || !strcmp(opt_crr,"no_dmn_var_nm")) PRN_DMN_VAR_NM=False; /* endif "no_nm_prn" */
-      if(!strcmp(opt_crr,"ppc") || !strcmp(opt_crr,"precision_preserving_compression") || !strcmp(opt_crr,"quantize")){
-        ppc_arg[ppc_nbr]=(char *)strdup(optarg);
-        ppc_nbr++;
-      } /* endif "ppc" */
+      if(!strcmp(opt_crr,"ppc") || !strcmp(opt_crr,"precision_preserving_compression") || !strcmp(opt_crr,"quantize")) ppc_arg[ppc_nbr++]=(char *)strdup(optarg);
       if(!strcmp(opt_crr,"rad") || !strcmp(opt_crr,"retain_all_dimensions") || !strcmp(opt_crr,"orphan_dimensions") || !strcmp(opt_crr,"rph_dmn")) RETAIN_ALL_DIMS=True;
       if(!strcmp(opt_crr,"ram_all") || !strcmp(opt_crr,"create_ram") || !strcmp(opt_crr,"diskless_all")) RAM_CREATE=True; /* [flg] Open (netCDF3) file(s) in RAM */
       if(!strcmp(opt_crr,"ram_all") || !strcmp(opt_crr,"open_ram") || !strcmp(opt_crr,"diskless_all")) RAM_OPEN=True; /* [flg] Create file in RAM */
       if(!strcmp(opt_crr,"rgr") || !strcmp(opt_crr,"regridding")){
         flg_rgr=True;
-        rgr_nbr++;
-        rgr_arg=(char **)nco_realloc(rgr_arg,rgr_nbr*sizeof(char *));
-        rgr_arg[rgr_nbr-1]=(char *)strdup(optarg);
+        rgr_arg=(char **)nco_realloc(rgr_arg,(rgr_nbr+1)*sizeof(char *));
+        rgr_arg[rgr_nbr++]=(char *)strdup(optarg);
       } /* endif "rgr" */
       if(!strcmp(opt_crr,"rgr_in")) rgr_in=(char *)strdup(optarg);
-      if(!strcmp(opt_crr,"rgr_out")) rgr_out=(char *)strdup(optarg);
       if(!strcmp(opt_crr,"rgr_grd_src")) rgr_grd_src=(char *)strdup(optarg);
       if(!strcmp(opt_crr,"rgr_grd_dst")) rgr_grd_dst=(char *)strdup(optarg);
-      if(!strcmp(opt_crr,"rgr_map")) rgr_map=(char *)strdup(optarg);
+      if(!strcmp(opt_crr,"rgr_map") || !strcmp(opt_crr,"map_file")){
+        flg_rgr=True;
+	rgr_map=(char *)strdup(optarg);
+      } /* endif rgr_map */
+      if(!strcmp(opt_crr,"rnr") || !strcmp(opt_crr,"rgr_rnr") || !strcmp(opt_crr,"renormalize")){
+        wgt_vld_thr=strtod(optarg,&sng_cnv_rcd);
+        if(*sng_cnv_rcd) nco_sng_cnv_err(optarg,"strtod",sng_cnv_rcd);
+      } /* endif rgr_rnr */
       if(!strcmp(opt_crr,"rgr_var")) rgr_var=(char *)strdup(optarg);
       if(!strcmp(opt_crr,"secret") || !strcmp(opt_crr,"scr") || !strcmp(opt_crr,"shh")){
         (void)fprintf(stdout,"Hidden/unsupported NCO options:\nCompiler used\t\t--cmp, --compiler\nCopyright\t\t--cpy, --copyright, --license\nHidden functions\t--scr, --ssh, --secret\nLibrary used\t\t--lbr, --library\nMemory clean\t\t--mmr_cln, --cln, --clean\nMemory dirty\t\t--mmr_drt, --drt, --dirty\nMPI implementation\t--mpi_implementation\nNo-clobber files\t--no_clb, --no-clobber\nPseudonym\t\t--pseudonym, -Y (ncra only)\nRegridding\t\t--rgr...\nSpinlock\t\t--spinlock\nStreams\t\t\t--srm\nSysconf\t\t\t--sysconf\nTest UDUnits\t\t--tst_udunits,'units_in','units_out','cln_sng'? \nVersion\t\t\t--vrs, --version\n\n");
@@ -759,6 +773,10 @@ main(int argc,char **argv)
     case 's': /* User specified delimiter string for printed output */
       dlm_sng=(char *)strdup(optarg);
       break;
+    case 't': /* Thread number */
+      thr_nbr=(int)strtol(optarg,&sng_cnv_rcd,NCO_SNG_CNV_BASE10);
+      if(*sng_cnv_rcd) nco_sng_cnv_err(optarg,"strtol",sng_cnv_rcd);
+      break;
     case 'u': /* Toggle printing dimensional units */
       PRN_DMN_UNITS_TGL=True;
       break;
@@ -825,7 +843,6 @@ main(int argc,char **argv)
 #endif /* !_LANGINFO_H */
 
   /* Initialize traversal table */
-
   (void)trv_tbl_init(&trv_tbl);
  
   /* Get program info for regressions tests */
@@ -834,14 +851,21 @@ main(int argc,char **argv)
   /* Process positional arguments and fill in filenames */
   fl_lst_in=nco_fl_lst_mk(argv,argc,optind,&fl_nbr,&fl_out,&FL_LST_IN_FROM_STDIN);
   
+  /* Initialize thread information */
+  thr_nbr=nco_openmp_ini(thr_nbr);
+  in_id_arr=(int *)nco_malloc(thr_nbr*sizeof(int));
+  trv_tbl->thr_nbr=thr_nbr;
+  trv_tbl->in_id_arr=in_id_arr;
+
   /* Parse filename */
   fl_in=nco_fl_nm_prs(fl_in,0,&fl_nbr,fl_lst_in,abb_arg_nbr,fl_lst_abb,fl_pth);
   /* Make sure file is on local system and is readable or die trying */
   fl_in=nco_fl_mk_lcl(fl_in,fl_pth_lcl,&FL_RTR_RMT_LCN);
   /* Open file using appropriate buffer size hints and verbosity */
   if(RAM_OPEN) md_open=NC_NOWRITE|NC_DISKLESS; else md_open=NC_NOWRITE;
-  rcd+=nco_fl_open(fl_in,md_open,&bfr_sz_hnt,&in_id);
-
+  for(thr_idx=0;thr_idx<thr_nbr;thr_idx++) rcd+=nco_fl_open(fl_in,md_open,&bfr_sz_hnt,in_id_arr+thr_idx);
+  in_id=in_id_arr[0];
+  
   /* Construct GTT (Group Traversal Table), check -v and -g input names and create extraction list */
   (void)nco_bld_trv_tbl(in_id,trv_pth,lmt_nbr,lmt_arg,aux_nbr,aux_arg,MSA_USR_RDR,FORTRAN_IDX_CNV,grp_lst_in,grp_lst_in_nbr,var_lst_in,xtr_nbr,EXTRACT_ALL_COORDINATES,GRP_VAR_UNN,GRP_XTR_VAR_XCL,EXCLUDE_INPUT_LIST,EXTRACT_ASSOCIATED_COORDINATES,nco_pck_plc_nil,&flg_dne,trv_tbl);
 
@@ -936,70 +960,94 @@ main(int argc,char **argv)
 
     /* Regridding */
     if(flg_rgr){
-      rgr_sct rgr_nfo;
+      rgr_sct *rgr_nfo;
       /* Initialize regridding structure */
       rgr_in=(char *)strdup(fl_in);
-      rcd=nco_rgr_ini(in_id,rgr_arg,rgr_nbr,rgr_in,rgr_out,rgr_grd_src,rgr_grd_dst,rgr_map,rgr_var,&rgr_nfo);
-      rgr_nfo.fl_out_tmp=nco_fl_out_open(rgr_nfo.fl_out,FORCE_APPEND,FORCE_OVERWRITE,fl_out_fmt,&bfr_sz_hnt,RAM_CREATE,RAM_OPEN,WRT_TMP_FL,&rgr_nfo.out_id);
+      rgr_out=(char *)strdup(fl_out);
+      rgr_nfo=nco_rgr_ini(in_id,rgr_arg,rgr_nbr,rgr_in,rgr_out,rgr_grd_src,rgr_grd_dst,rgr_map,rgr_var,wgt_vld_thr);
+      rgr_nfo->fl_out_tmp=nco_fl_out_open(rgr_nfo->fl_out,FORCE_APPEND,FORCE_OVERWRITE,fl_out_fmt,&bfr_sz_hnt,RAM_CREATE,RAM_OPEN,WRT_TMP_FL,&out_id);
+
+      /* Copy Global Metadata */
+      rgr_nfo->out_id=out_id;
+      //      out_id=rgr_nfo->out_id;
+      nco_bool PCK_ATT_CPY=True; /* [flg] Copy attributes "scale_factor", "add_offset" */
+      (void)nco_att_cpy(in_id,out_id,NC_GLOBAL,NC_GLOBAL,PCK_ATT_CPY);
+      /* Catenate time-stamped command line to "history" global attribute */
+      if(HISTORY_APPEND) (void)nco_hst_att_cat(out_id,cmd_ln);
+      if(HISTORY_APPEND) (void)nco_vrs_att_cat(out_id);
+      if(thr_nbr > 0 && HISTORY_APPEND) (void)nco_thr_att_cat(out_id,thr_nbr);
+
       /* Regrid fields */
-      rcd=nco_rgr_ctl(&rgr_nfo);
+      rcd=nco_rgr_ctl(rgr_nfo,trv_tbl);
       /* Change from NCO_NOERR to NC_NOERR */
       rcd=NC_NOERR;
+
+      /* Close output file and move it from temporary to permanent location */
+      (void)nco_fl_out_cls(rgr_nfo->fl_out,rgr_nfo->fl_out_tmp,out_id);
+
+      /* Free regridding structure */
+      rgr_nfo=nco_rgr_free(rgr_nfo);
     } /* endif !flg_rgr */
 
-    /* Initialize, decode, and set PPC information */
-    if(ppc_nbr > 0) nco_ppc_ini(in_id,&dfl_lvl,fl_out_fmt,ppc_arg,ppc_nbr,trv_tbl);
-
-    /* Verify output file format supports requested actions */
-    (void)nco_fl_fmt_vet(fl_out_fmt,cnk_nbr,dfl_lvl);
-
-    /* Open output file */
-    fl_out_tmp=nco_fl_out_open(fl_out,FORCE_APPEND,FORCE_OVERWRITE,fl_out_fmt,&bfr_sz_hnt,RAM_CREATE,RAM_OPEN,WRT_TMP_FL,&out_id);
+    if(!flg_rgr){
+      
+      /* Initialize, decode, and set PPC information */
+      if(ppc_nbr > 0) nco_ppc_ini(in_id,&dfl_lvl,fl_out_fmt,ppc_arg,ppc_nbr,trv_tbl);
+      
+      /* Verify output file format supports requested actions */
+      (void)nco_fl_fmt_vet(fl_out_fmt,cnk_nbr,dfl_lvl);
+      
+      /* Open output file */
+      fl_out_tmp=nco_fl_out_open(fl_out,FORCE_APPEND,FORCE_OVERWRITE,fl_out_fmt,&bfr_sz_hnt,RAM_CREATE,RAM_OPEN,WRT_TMP_FL,&out_id);
     
-    /* Create structure with all chunking information */
-    if(fl_out_fmt == NC_FORMAT_NETCDF4 || fl_out_fmt == NC_FORMAT_NETCDF4_CLASSIC) rcd+=nco_cnk_ini(in_id,fl_out,cnk_arg,cnk_nbr,cnk_map,cnk_plc,cnk_min_byt,cnk_sz_byt,cnk_sz_scl,&cnk);
+      /* Initialize chunking from user-specified inputs */
+      if(fl_out_fmt == NC_FORMAT_NETCDF4 || fl_out_fmt == NC_FORMAT_NETCDF4_CLASSIC) rcd+=nco_cnk_ini(in_id,fl_out,cnk_arg,cnk_nbr,cnk_map,cnk_plc,cnk_min_byt,cnk_sz_byt,cnk_sz_scl,&cnk);
 
-    /* Define extracted groups, variables, and attributes in output file */
-    (void)nco_xtr_dfn(in_id,out_id,&cnk,dfl_lvl,gpe,md5,PRN_GLB_METADATA,PRN_VAR_METADATA,RETAIN_ALL_DIMS,nco_pck_plc_nil,rec_dmn_nm,trv_tbl);
+      /* Define extracted groups, variables, and attributes in output file */
+      CPY_GRP_METADATA = FORCE_APPEND ? False : PRN_GLB_METADATA;
+      (void)nco_xtr_dfn(in_id,out_id,&cnk,dfl_lvl,gpe,md5,CPY_GRP_METADATA,PRN_VAR_METADATA,RETAIN_ALL_DIMS,nco_pck_plc_nil,rec_dmn_nm,trv_tbl);
 
-    /* Catenate time-stamped command line to "history" global attribute */
-    if(HISTORY_APPEND) (void)nco_hst_att_cat(out_id,cmd_ln);
-    if(HISTORY_APPEND) (void)nco_vrs_att_cat(out_id);
+      /* Catenate time-stamped command line to "history" global attribute */
+      if(HISTORY_APPEND) (void)nco_hst_att_cat(out_id,cmd_ln);
+      if(HISTORY_APPEND && FORCE_APPEND) (void)nco_prv_att_cat(fl_in,in_id,out_id);
+      if(HISTORY_APPEND) (void)nco_vrs_att_cat(out_id);
 #ifdef ENABLE_MPI
-    if(prc_rnk == rnk_mgr)
-      if(prc_nbr > 0 && HISTORY_APPEND) (void)nco_mpi_att_cat(out_id,prc_nbr);
+      if(prc_rnk == rnk_mgr)
+	if(prc_nbr > 0 && HISTORY_APPEND) (void)nco_mpi_att_cat(out_id,prc_nbr);
 #endif /* !ENABLE_MPI */
+      
+      /* Turn off default filling behavior to enhance efficiency */
+      nco_set_fill(out_id,NC_NOFILL,&fll_md_old);
+      
+      /* Take output file out of define mode */
+      if(hdr_pad == 0UL){
+	(void)nco_enddef(out_id);
+      }else{
+	(void)nco__enddef(out_id,hdr_pad);
+	if(nco_dbg_lvl >= nco_dbg_scl) (void)fprintf(stderr,"%s: INFO Padding header with %lu extra bytes\n",nco_prg_nm_get(),(unsigned long)hdr_pad);
+      } /* hdr_pad */
 
-    /* Turn off default filling behavior to enhance efficiency */
-    nco_set_fill(out_id,NC_NOFILL,&fll_md_old);
+      /* [fnc] Open unformatted binary data file for writing */
+      if(fl_bnr) fp_bnr=nco_bnr_open(fl_bnr);
+      
+      /* Timestamp end of metadata setup and disk layout */
+      rcd+=nco_ddra((char *)NULL,(char *)NULL,&ddra_info);
+      ddra_info.tmr_flg=nco_tmr_rgl;
+      /* Write extracted data to output file */
+      if(PRN_VAR_DATA) (void)nco_xtr_wrt(in_id,out_id,gpe,fp_bnr,md5,HAVE_LIMITS,trv_tbl);
+      
+      /* [fnc] Close unformatted binary data file */
+      if(fp_bnr) (void)nco_bnr_close(fp_bnr,fl_bnr);
+      
+      if(nco_dbg_lvl_get() == 14){
+	(void)nco_wrt_trv_tbl(in_id,trv_tbl,True);
+	(void)nco_wrt_trv_tbl(out_id,trv_tbl,True);
+      } /* endif dbg */
 
-    /* Take output file out of define mode */
-    if(hdr_pad == 0UL){
-      (void)nco_enddef(out_id);
-    }else{
-      (void)nco__enddef(out_id,hdr_pad);
-      if(nco_dbg_lvl >= nco_dbg_scl) (void)fprintf(stderr,"%s: INFO Padding header with %lu extra bytes\n",nco_prg_nm_get(),(unsigned long)hdr_pad);
-    } /* hdr_pad */
-
-    /* [fnc] Open unformatted binary data file for writing */
-    if(fl_bnr) fp_bnr=nco_bnr_open(fl_bnr);
-
-    /* Timestamp end of metadata setup and disk layout */
-    rcd+=nco_ddra((char *)NULL,(char *)NULL,&ddra_info);
-    ddra_info.tmr_flg=nco_tmr_rgl;
-    /* Write extracted data to output file */
-    if(PRN_VAR_DATA) (void)nco_xtr_wrt(in_id,out_id,gpe,fp_bnr,md5,HAVE_LIMITS,trv_tbl);
-
-    /* [fnc] Close unformatted binary data file */
-    if(fp_bnr) (void)nco_bnr_close(fp_bnr,fl_bnr);
-
-    if(nco_dbg_lvl_get() == 14){
-      (void)nco_wrt_trv_tbl(in_id,trv_tbl,True);
-      (void)nco_wrt_trv_tbl(out_id,trv_tbl,True);
-    } /* endif dbg */
-
-    /* Close output file and move it from temporary to permanent location */
-    (void)nco_fl_out_cls(fl_out,fl_out_tmp,out_id);
+      /* Close output file and move it from temporary to permanent location */
+      (void)nco_fl_out_cls(fl_out,fl_out_tmp,out_id);
+    
+    } /* flg_rgr */
     
   }else{ /* !fl_out */
 
@@ -1132,8 +1180,8 @@ main(int argc,char **argv)
   /* goto close_and_free */
 close_and_free: 
 
-  /* Close input netCDF file */
-  nco_close(in_id);
+  /* Close input netCDF files */
+  for(thr_idx=0;thr_idx<thr_nbr;thr_idx++) nco_close(in_id_arr[thr_idx]);
 
   /* Remove local copy of file */
   if(FL_RTR_RMT_LCN && RM_RMT_FL_PST_PRC) (void)nco_fl_rm(fl_in);
@@ -1143,12 +1191,11 @@ close_and_free:
     /* ncks-specific memory */
     if(fl_bnr) fl_bnr=(char *)nco_free(fl_bnr);
     if(rec_dmn_nm) rec_dmn_nm=(char *)nco_free(rec_dmn_nm); 
-    /* DYW */
     if(fl_scrip){
       fl_scrip=(char *)nco_free(fl_scrip);
       idx=0;
       if(nco_dbg_lvl > nco_dbg_fl) while(sld_nfo[idx].key) nco_kvm_prn(sld_nfo[idx++]);
-      if(sld_nfo) nco_kvm_free(sld_nfo);
+      if(sld_nfo) sld_nfo=nco_kvm_lst_free(sld_nfo,idx);
     } /* endif fl_scrip */
     /* NCO-generic clean-up */
     /* Free individual strings/arrays */
@@ -1160,6 +1207,7 @@ close_and_free:
     if(fl_out_tmp) fl_out_tmp=(char *)nco_free(fl_out_tmp);
     if(fl_pth) fl_pth=(char *)nco_free(fl_pth);
     if(fl_pth_lcl) fl_pth_lcl=(char *)nco_free(fl_pth_lcl);
+    if(in_id_arr) in_id_arr=(int *)nco_free(in_id_arr);
     if(spr_nmr) spr_nmr=(char *)nco_free(spr_nmr);
     if(spr_chr) spr_chr=(char *)nco_free(spr_chr);
     /* Free lists of strings */
@@ -1172,7 +1220,6 @@ close_and_free:
     for(idx=0;idx<aux_nbr;idx++) aux_arg[idx]=(char *)nco_free(aux_arg[idx]);
     for(idx=0;idx<lmt_nbr;idx++) lmt_arg[idx]=(char *)nco_free(lmt_arg[idx]);
     for(idx=0;idx<ppc_nbr;idx++) ppc_arg[idx]=(char *)nco_free(ppc_arg[idx]);
-    if(rgr_nbr > 0) rgr_arg=nco_sng_lst_free(rgr_arg,rgr_nbr);
     /* Free chunking information */
     for(idx=0;idx<cnk_nbr;idx++) cnk_arg[idx]=(char *)nco_free(cnk_arg[idx]);
     if(cnk_nbr > 0) cnk.cnk_dmn=(cnk_dmn_sct **)nco_cnk_lst_free(cnk.cnk_dmn,cnk_nbr);
