@@ -289,10 +289,10 @@ extern "C" {
 # define NCO_VERSION_MAJOR 4
 #endif /* !NCO_VERSION_MAJOR */
 #ifndef NCO_VERSION_MINOR
-# define NCO_VERSION_MINOR 4
+# define NCO_VERSION_MINOR 5
 #endif /* !NCO_VERSION_MINOR */
 #ifndef NCO_VERSION_PATCH
-# define NCO_VERSION_PATCH 9
+# define NCO_VERSION_PATCH 0
 #endif /* !NCO_VERSION_PATCH */
 #ifndef NCO_VERSION_NOTE
 # define NCO_VERSION_NOTE  "" /* May be blank */
@@ -302,7 +302,7 @@ extern "C" {
 # define NCO_LIB_VERSION ( NCO_VERSION_MAJOR * 100 + NCO_VERSION_MINOR * 10 + NCO_VERSION_PATCH )
 #endif /* !NCO_LIB_VERSION */
 #ifndef NCO_VERSION
-# define NCO_VERSION "4.4.9"
+# define NCO_VERSION "4.5.0"
 #endif /* !NCO_VERSION */
 
 /* Compatibility tokens new to netCDF4 netcdf.h: */
@@ -879,6 +879,7 @@ extern "C" {
   
   /* Regrid structure */
   typedef struct{ /* rgr_sct */
+    // File names specifiable with individual command line switches
     char *drc_tps; /* [sng] Data directory for Tempest grids, meshes, and weights */
     char *fl_grd_src; /* [sng] File containing input grid */
     char *fl_grd_dst; /* [sng] File containing destination grid */
@@ -886,15 +887,30 @@ extern "C" {
     char *fl_out; /* [sng] File containing regridded fields */
     char *fl_out_tmp; /* [sng] Temporary file containing regridded fields */
     char *fl_map; /* [sng] File containing mapping weights from source to destination grid */
-    char **rgr_arg; /* [sng] Regridding arguments */
     char *var_nm; /* [sng] Variable for special regridding treatment */
-    int rgr_nbr; /* [nbr] Number of regridding arguments */
+    // Grid names specifiable with key-value syntax
+    char **rgr_arg; /* [sng] Regridding arguments */
+    char *area_nm; /* [sng] Name of variable containing gridcell area */
+    char *bnd_nm; /* [sng] Name of dimension to employ for spatial bounds */
+    char *bnd_tm_nm; /* [sng] Name of dimension to employ for temporal bounds */
+    char *col_nm; /* [sng] Name of horizontal spatial dimension on unstructured grid */
+    char *lat_bnd_nm; /* [sng] Name of rectangular boundary variable for latitude */
+    char *lat_nm; /* [sng] Name of dimension to recognize as latitude */
+    char *lat_vrt_nm; /* [sng] Name of non-rectangular boundary variable for latitude */
+    char *lat_wgt_nm; /* [sng] Name of variable containing latitude weights */
+    char *lon_bnd_nm; /* [sng] Name of rectangular boundary variable for longitude */
+    char *lon_nm; /* [sng] Name of dimension to recognize as longitude */
+    char *lon_vrt_nm; /* [sng] Name of non-rectangular boundary variable for longitude */
+    char *vrt_nm; /* [sng] Name of dimension to employ for vertices */
+    double wgt_vld_thr; /* [frc] Weight threshold for valid destination value */
     int in_id; /* [id] Input netCDF file ID */
     int out_id; /* [id] Output netCDF file ID */
+    int rgr_nbr; /* [nbr] Number of regridding arguments */
     nco_bool flg_usr_rqs; /* [flg] User requested regridding */
     nco_bool flg_grd_src; /* [flg] User-specified input grid */
     nco_bool flg_grd_dst; /* [flg] User-specified destination grid */
     nco_bool flg_map; /* [flg] User-specified mapping weights */
+    nco_bool flg_rnr; /* [flg] Renormalize destination values by valid area */
   } rgr_sct;
 
   /* Key-value structure */
@@ -992,7 +1008,7 @@ extern "C" {
   } aux_crd_sct; 
 
   /* GTT Variable dimensions:
-  Dimension have name and size, and can have an associated variable (coordinate variable) */
+     Dimensions have name and size, and maybe an associated (coordinate) variable */
   typedef struct{ 
     char *dmn_nm_fll;        /* [sng] Full dimension name */
     char *dmn_nm;            /* [sng] Dimension name */
@@ -1058,6 +1074,7 @@ extern "C" {
     nco_bool flg_ncs;                 /* [flg] Group is ancestor of specified group or variable */
     nco_bool flg_nsx;                 /* [flg] Object matches intersection criteria */
     nco_bool flg_rcr;                 /* [flg] Extract group recursively */
+    nco_bool flg_rgr;                 /* [flg] Regrid variable */ 
     nco_bool flg_unn;                 /* [flg] Object matches union criteria */
     nco_bool flg_vfp;                 /* [flg] Variable matches full path specification */
     nco_bool flg_vsg;                 /* [flg] Variable selected because group matches */
@@ -1153,6 +1170,8 @@ extern "C" {
     int nsm_nbr;            /* [nbr] (ncge) Number of ensembles (i.e., number in first file) */ 
     nsm_sct *nsm;           /* [lst] (ncge) List of ensembles (size is nsm_nbr) */ 
     char *nsm_sfx;          /* [sng] (ncge) Ensemble suffix (e.g., /cesm + _avg). Store here instead of passing as function parameters (ncge only) */
+    int thr_nbr; /* [nbr] Thread number Option t */
+    int *in_id_arr; /* [id] netCDF file IDs used by OpenMP code */
   } trv_tbl_sct;
  
   /* GPE duplicate name check structure */
