@@ -347,3 +347,69 @@ nco_mss_val_get /* [fnc] Update number of attributes, missing_value of variable
 
 } /* end nco_mss_val_get() */
 
+nco_bool /* O [flg] Variable has missing value */
+nco_mss_val_get_dbl /* [fnc] Return missing_value of variable, if any, as double precision number */
+(const int nc_id, /* I [id] netCDF input-file ID */
+ const int var_id, /* I [id] netCDF variable ID */
+ double *mss_val_dbl) /* O [frc] Missing value in double precision */
+{
+  /* Purpose: Return missing_value of variable, if any, as double precision number
+     Basically this is a stripped-down, fast version of nco_mss_val_get()
+     Created for use in regridding
+     No matter what type missing_value is on disk, this routine returns a double precision value */
+  
+  static nco_bool WRN_FIRST=True; /* [flg] No warnings yet for _FillValue/missing_value mismatch */
+  
+  char att_nm[NC_MAX_NAME];
+  char var_nm[NC_MAX_NAME];
+  int idx;
+  int var_nbr_att;
+  long att_sz;
+  nco_bool has_fll_val=False; /* [flg] Has _FillValue attribute */
+  nco_bool has_mss_val=False; /* [flg] Has missing value attribute */
+  nc_type att_typ;
+  
+  /* Refresh number of attributes for variable */
+  (void)nco_inq_varnatts(nc_id,var_id,&var_nbr_att);
+  
+  for(idx=0;idx<var_nbr_att;idx++){
+    (void)nco_inq_attname(nc_id,var_id,idx,att_nm);
+    if(WRN_FIRST && !(int)strcasecmp(att_nm,nco_not_mss_val_sng_get())) has_fll_val=True;
+    
+    if((int)strcasecmp(att_nm,nco_mss_val_sng_get())) continue;
+    (void)nco_inq_att(nc_id,var_id,att_nm,&att_typ,&att_sz);
+    if(att_sz != 1L){
+      (void)nco_inq_varname(nc_id,var_id,var_nm);
+      (void)fprintf(stderr,"%s: WARNING the \"%s\" attribute for %s has %li elements and so will not be used\n",nco_prg_nm_get(),att_nm,var_nm,att_sz);
+      continue;
+    } /* end if */
+    if(att_typ == NC_CHAR || att_typ == NC_STRING){
+      (void)nco_inq_varname(nc_id,var_id,var_nm);
+      (void)fprintf(stderr,"%s: WARNING the \"%s\" attribute for %s has type %s and so will not be used\n",nco_prg_nm_get(),att_nm,var_nm,nco_typ_sng(att_typ));
+      continue;
+    } /* end if */
+    /* If we got this far then retrieve attribute */
+    has_mss_val=True;
+    /* Oddly, ARM uses NC_CHAR for type of missing_value, so make allowances for this */
+    (void)nco_get_att(nc_id,var_id,att_nm,mss_val_dbl,NC_DOUBLE);
+    break;
+  } /* end loop over att */
+
+  /* Always warn when NCO looks for _FillValue but file has missing_value, and/or
+     always warn when NCO looks for missing_value but file has _FillValue.
+     20101129: This is a long warning, only print when nco_dbg_lvl > 0 */
+  if(nco_dbg_lvl_get() >= nco_dbg_std && has_fll_val && !has_mss_val && WRN_FIRST){
+    char sa[1000];
+    char sa1[1000];
+    char sa2[1000]; 
+    WRN_FIRST=False;
+    (void)sprintf(sa,"%s: WARNING Variable %s has attribute \"%s\" but not \"%s\". To comply with netCDF conventions, NCO ignores values that equal the %s attribute when performing arithmetic.",nco_prg_nm_get(),var_nm,nco_not_mss_val_sng_get(), nco_mss_val_sng_get(),nco_mss_val_sng_get()); 
+    (void)sprintf(sa1," Confusingly, values equal to the missing_value should also be neglected. However, it is tedious and (possibly) computationally expensive to check each value against multiple missing values during arithmetic on large variables. So NCO thinks that processing variables with a \"%s\" attribute and no \"%s\" attribute may produce undesired arithmetic results (i.e., where values that were intended to be neglected were not, in fact, neglected).",nco_not_mss_val_sng_get(),nco_mss_val_sng_get());
+    (void)sprintf(sa2, " We suggest you rename all \"%s\" attributes to \"%s\" or include both \"%s\" and \"%s\" attributes (with the _same values_) for all variables that have either attribute. Because it is long, this message is only printed once per operator even though multiple variables may have the same attribute configuration. More information on missing values is given at:\nhttp://nco.sf.net/nco.html#mss_val\nExamples of renaming attributes are at:\nhttp://nco.sf.net/nco.html#xmp_ncrename\nExamples of creating and deleting attributes are at:\nhttp://nco.sf.net/nco.html#xmp_ncatted\n",nco_not_mss_val_sng_get(),nco_mss_val_sng_get(),nco_not_mss_val_sng_get(),nco_mss_val_sng_get());
+    (void)fprintf(stderr,"%s%s%s",sa,sa1,sa2); 
+  } /* endif missing_value is and _FillValue is not defined */
+
+  return has_mss_val;
+  
+} /* end nco_mss_val_get_dbl() */
+
