@@ -603,16 +603,15 @@ sng_trm_trl_zro /* [fnc] Trim zeros trailing decimal point and preceding exponen
 
 kvm_sct /* O [sct] Key-value pair */
 nco_sng2kvm /* [fnc] Parse string into key-value pair */
-(char *sng, /* I [sng] String to parse, including "=" */
- kvm_sct kvm) /* O [sct] Key-value pair */
+(char *sng) /* I [sng] String to parse, including "=" */
 {
   /* Purpose: Convert string separated by single delimiter into two strings
      Routine converts argument "--ppc key1,key2,...,keyN=val" into kvm.key="key1,key2,...keyN" and kvm.val=val
      e.g., routine converts argument "--ppc one,two=3" into kvm.key="one,two" and kvm.val=3 */
   char *tkn_sng;
   const char dlm[]="="; /* [sng] Delimiter */
-  
   int arg_idx=0; /* [nbr] */
+  kvm_sct kvm;
 
   /* NB: Replace strtok() by strsep()? strtok() does not handle consecutive delimiters well */
   tkn_sng=strtok(sng,dlm);
@@ -653,20 +652,20 @@ nco_sng_strip /* [fnc] Strip leading and trailing white space */
   return sng;
 } /* end nco_sng_strip() */
 
-void
-nco_kvm_free /* [fnc] Relinquish dynamic memory from list of kvm structures */
-(kvm_sct *kvm) /* I/O [sct] List of kvm structures */
+kvm_sct * /* O [sct] Pointer to free'd kvm list */
+nco_kvm_lst_free /* [fnc] Relinquish dynamic memory from list of kvm structures */
+(kvm_sct *kvm, /* I/O [sct] List of kvm structures */
+ const int kvm_nbr) /* I [nbr] Number of kvm structures */
 {
   /* Purpose: Relinquish dynamic memory from list of kvm structures
      End of list is indicated by NULL in key slot */
-  int idx=0;
-  while(kvm[idx].key){
-    kvm[idx].key=(char *)nco_free(kvm[idx].key);
-    kvm[idx].val=(char *)nco_free(kvm[idx].val);
-    idx++;
-  } /* end while */
-  kvm=(kvm_sct *)nco_free(kvm);
-} /* end nco_kvm_free() */
+  for(int kvm_idx=0;kvm_idx<kvm_nbr;kvm_idx++){
+    kvm[kvm_idx].key=(char *)nco_free(kvm[kvm_idx].key);
+    kvm[kvm_idx].val=(char *)nco_free(kvm[kvm_idx].val);
+  } /* end for */
+  if(kvm) kvm=(kvm_sct *)nco_free(kvm);
+  return kvm;
+} /* end nco_kvm_lst_free() */
 
 void
 nco_kvm_prn(kvm_sct kvm)
